import { type PropertyValues } from 'lit';
import { CodeMirrorExtensionElement } from './cm-extention-element.js';
import { type TagSpec } from '@codemirror/lang-html';
import type { Parser } from '@lezer/common';
export declare class CodeMirrorLangJavascript extends CodeMirrorExtensionElement {
    /**
     * By default, the syntax tree will highlight mismatched closing
     * tags. Set this to `true` to turn that off (for example when you
     * expect to only be parsing a fragment of HTML text, not a full
     * document).
     */
    noMatchClosingTags: boolean;
    selfClosingTags: boolean;
    /**
     * Determines whether [`autoCloseTags`](https://codemirror.net/6/docs/ref/#lang-html.autoCloseTags)
     * is included in the support extensions. Defaults to false.
     */
    noAutoCloseTags: boolean;
    /**
     * Add additional tags that can be completed.
     */
    extraTags?: Record<string, TagSpec>;
    /**
     * Add additional completable attributes to all tags.
     */
    extraGlobalAttributes?: Record<string, null | readonly string[]>;
    /**
     * Register additional languages to parse the content of specific
     * tags. If given, `attrs` should be a function that, given an
     * object representing the tag's attributes, returns `true` if this
     * language applies.
     */
    nestedLanguages?: NestedLang[];
    /**
     * Register additional languages to parse attribute values with.
     */
    nestedAttributes?: NestedAttr[];
    update(changedProperties: PropertyValues<this>): void;
}
export type NestedLang = {
    tag: string;
    attrs?: (attrs: {
        [attr: string]: string;
    }) => boolean;
    parser: Parser;
};
export type NestedAttr = {
    name: string;
    tagName?: string;
    parser: Parser;
};
//# sourceMappingURL=cm-lang-html.d.ts.map