var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
import { css, html, LitElement } from 'lit';
import { customElement, property } from 'lit/decorators.js';
import { ContextProvider } from '@lit-labs/context';
import { EditorView, keymap, highlightSpecialChars, drawSelection, highlightActiveLine, dropCursor, rectangularSelection, crosshairCursor, lineNumbers, highlightActiveLineGutter, } from '@codemirror/view';
import { Compartment, EditorState } from '@codemirror/state';
import { defaultHighlightStyle, syntaxHighlighting, indentOnInput, bracketMatching, foldGutter, foldKeymap, } from '@codemirror/language';
import { defaultKeymap, history, historyKeymap } from '@codemirror/commands';
import { searchKeymap, highlightSelectionMatches } from '@codemirror/search';
import { autocompletion, completionKeymap, closeBrackets, closeBracketsKeymap, } from '@codemirror/autocomplete';
import { lintKeymap } from '@codemirror/lint';
import { extensionsContext } from './codemirror-context.js';
let CodeMirrorEditor = class CodeMirrorEditor extends LitElement {
    static { this.styles = css `
    :host {
      display: block;
    }
  `; }
    constructor() {
        super();
        this._addedExtensions = new Set();
        this._addedExtensionCompartment = new Compartment();
        new ContextProvider(this, extensionsContext, this);
    }
    render() {
        return html `<h1>codemirror-editor</h1>`;
    }
    addExtensions(extensions) {
        for (const extension of extensions) {
            this._addedExtensions.add(extension);
        }
        console;
        const effect = this._addedExtensionCompartment.reconfigure([...this._addedExtensions]);
        this.editorView.dispatch({ effects: [effect] });
    }
    removeExtensions(extensions) {
        for (const extension of extensions) {
            this._addedExtensions.delete(extension);
        }
        const effect = this._addedExtensionCompartment.reconfigure([...this._addedExtensions]);
        this.editorView?.dispatch({ effects: [effect] });
    }
    async firstUpdated() {
        this.editorView = new EditorView({
            doc: "console.log('hello')\n",
            extensions: [
                lineNumbers(),
                highlightActiveLineGutter(),
                highlightSpecialChars(),
                history(),
                foldGutter(),
                drawSelection(),
                dropCursor(),
                EditorState.allowMultipleSelections.of(true),
                indentOnInput(),
                syntaxHighlighting(defaultHighlightStyle, { fallback: true }),
                bracketMatching(),
                closeBrackets(),
                autocompletion(),
                rectangularSelection(),
                crosshairCursor(),
                highlightActiveLine(),
                highlightSelectionMatches(),
                keymap.of([
                    ...closeBracketsKeymap,
                    ...defaultKeymap,
                    ...searchKeymap,
                    ...historyKeymap,
                    ...foldKeymap,
                    ...completionKeymap,
                    ...lintKeymap,
                ]),
                this._addedExtensionCompartment.of([]),
            ],
            parent: this.shadowRoot,
        });
    }
};
__decorate([
    property({ attribute: false })
], CodeMirrorEditor.prototype, "editorView", void 0);
CodeMirrorEditor = __decorate([
    customElement('codemirror-editor')
], CodeMirrorEditor);
export { CodeMirrorEditor };
//# sourceMappingURL=em-editor.js.map